@@ -11,20 +11,14 @@ use once_cell::sync::Lazy;
 use bytes::Buf;
 use bytes::BufMut;
 
-use crate::core::Decoder;
+use crate::core::{Encoder, Decoder};
 use crate::core::DecoderVarInt;
-use crate::core::Encoder;
 use crate::core::EncoderVarInt;
 use crate::core::Version;
-use crate::derive::Decode;
-use crate::derive::Encode;
 
 use crate::batch::Batch;
 use crate::Offset;
 
-#[deprecated(since = "0.5.1", note = "Use 'Record' instead")]
-pub type DefaultRecord = Record<RecordData>;
-
 /// maximum text to display
 static MAX_STRING_DISPLAY: Lazy<usize> = Lazy::new(|| {
     let var_value = std::env::var("FLV_MAX_STRING_DISPLAY").unwrap_or_default();
@@ -70,9 +64,6 @@ impl<K: Into<Vec<u8>>> From<K> for RecordKey {
     }
 }
 
-#[deprecated(since = "0.5.1", note = "Use 'RecordData' instead")]
-pub type DefaultAsyncBuffer = RecordData;
-
 /// A type containing the data contents of a Record.
 ///
 /// The `RecordData` type provides useful conversions for
@@ -82,19 +73,9 @@ pub type DefaultAsyncBuffer = RecordData;
 /// [the Producer API] as an example.
 ///
 /// [the Producer API]: https://docs.rs/fluvio/producer/TopicProducer::send
-#[derive(Default)]
+#[derive(Clone, Default, PartialEq)]
 pub struct RecordData(Bytes);
 
-impl RecordData {
-    #[deprecated(since = "0.5.1", note = "Use 'From::from' instead")]
-    pub fn new<T>(val: T) -> Self
-    where
-        T: Into<Bytes>,
-    {
-        Self(val.into())
-    }
-}
-
 impl RecordData {
     pub fn len(&self) -> usize {
         self.0.len()
@@ -327,7 +308,7 @@ impl Encoder for RecordSet {
     }
 }
 
-#[derive(Decode, Encode, Default, Debug)]
+#[derive(Decoder, Encoder, Default, Debug)]
 pub struct RecordHeader {
     attributes: i8,
     #[varint]
@@ -422,10 +403,12 @@ where
 
 impl<B: Debug> Debug for Record<B> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        writeln!(f, "{:?}", &self.preamble)?;
-        writeln!(f, "{:?}", &self.key)?;
-        writeln!(f, "{:?}", &self.value)?;
-        write!(f, "{:?}", &self.headers)
+        f.debug_struct("Record")
+            .field("preamble", &self.preamble)
+            .field("key", &self.key)
+            .field("value", &self.value)
+            .field("headers", &self.headers)
+            .finish()
     }
 }
 
